# bork [![Build Status][build-status-link]][build-status-img]

bork bork bork

[build-status-link]: https://api.cirrus-ci.com/github/duckinator/bork.svg
[build-status-img]: https://cirrus-ci.com/github/duckinator/bork

## Installation

```
$ pip3 install bork
```

## Usage

BORK BORK BORK BORK BORK (TODO)

## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/duckinator/bork. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](http://contributor-covenant.org) code of conduct.

## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

## Code of Conduct

Everyone interacting in the bork project’s codebases, issue trackers, chat rooms and mailing lists is expected to follow the [code of conduct](https://github.com/duckinator/bork/blob/master/CODE_OF_CONDUCT.md).
